Module filter

Module filter 

Structs

FileFilter
Filters file paths based on glob include/exclude patterns.

Functions

is_binary
Returns true if the content appears to be a binary file.
is_minified
Returns true if the content appears to be minified.