Structs
- File
Filter - Filters file paths based on glob include/exclude patterns.
Functions
- is_
binary - Returns
trueif the content appears to be a binary file. - is_
minified - Returns
trueif the content appears to be minified.
true if the content appears to be a binary file.true if the content appears to be minified.